@@ -9,12 +9,10 @@ enum hashid {
 	MHASH_SHA1,
 	MHASH_HAVAL256,
 	MHASH_RIPEMD160 = 5,
-	MHASH_SNEFRU,
-	MHASH_TIGER,
+	MHASH_TIGER = 7,
 	MHASH_GOST,
 	MHASH_CRC32B,
-	MHASH_MD2 = 10,
-	MHASH_HAVAL192,
+	MHASH_HAVAL192=11,
 	MHASH_HAVAL160,
 	MHASH_HAVAL128
 };
